@@ -1,7 +1,6 @@
-/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*-  */
 /*
  * main.c
- * Copyright (C) 2015 Georges Basile Stavracas Neto <georges.stavracas@gmail.com>
+ * Copyright (C) 2015-2020 Georges Basile Stavracas Neto <georges.stavracas@gmail.com>
  *
  * gnome-todo is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -18,21 +17,26 @@
  */
 
 #include "gtd-application.h"
+#include "gtd-utils-private.h"
 
 #include <config.h>
 #include <glib/gi18n.h>
 
 gint
-main (gint  argc,
-      char *argv[])
+main (gint    argc,
+      gchar **argv)
 {
-  g_autoptr (GtdApplication) app;
+  g_autoptr (GtdApplication) app = NULL;
+  g_autofree gchar *program_name = NULL;
+
+  gtd_ensure_types ();
 
   bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-  g_set_application_name (_("To Do"));
+  program_name = g_strconcat (_("To Do"), NAME_SUFFIX, NULL);
+  g_set_application_name (program_name);
 
   app = gtd_application_new ();
   g_application_set_default (G_APPLICATION (app));
